# Contributing

If you discover issues, have ideas for improvements or new features, or
want to contribute a new module, please report them to the
[issue tracker][1] of the repository or submit a pull request. Please,
try to follow these guidelines when you do so.

## Issue reporting

* Check that the issue has not already been reported.
* Check that the issue has not already been fixed in the latest code
  (a.k.a. `develop`).
* Be clear, concise and precise in your description of the problem.
* Open an issue with a descriptive title and a summary in grammatically correct,
  complete sentences.
* Include any relevant code to the issue summary.

## Pull requests

* Branch *develop* is for new features/bugfix. *master* branch is the stable code.
* Use a topic branch to easily amend a pull request later, if necessary.
* Write [good commit messages][2].
* Open a [pull request][3] that relates to *only* one subject with a clear title
  and description in grammatically correct, complete sentences.


[1]: https://github.com/nlamirault/kylin/issues
[2]: http://tbaggery.com/2008/04/19/a-note-about-git-commit-messages.html
[3]: https://help.github.com/articles/using-pull-requests
